@@ -6,7 +6,7 @@ use Net::Stomp::Frame;
 use Carp qw(longmess);
 use base 'Class::Accessor::Fast';
 use Net::Stomp::StupidLogger;
-our $VERSION = '0.56';
+our $VERSION = '0.57';
 
 __PACKAGE__->mk_accessors( qw(
     current_host failover hostname hosts port select serial session_id socket ssl
@@ -360,12 +360,23 @@ sub ack {
     return 1;
 }
 
+sub nack {
+    my ( $self, $conf ) = @_;
+    $conf = { %$conf };
+    my $id    = $conf->{frame}->headers->{'message-id'};
+    delete $conf->{frame};
+    my $frame = Net::Stomp::Frame->new(
+        { command => 'NACK', headers => { 'message-id' => $id, %$conf } } );
+    $self->send_frame($frame);
+    return 1;
+}
+
 sub send_frame {
     my ( $self, $frame ) = @_;
     # see if we're connected before we try to syswrite()
-    if (not defined $self->_connected) {
+    if (not $self->_connected) {
         $self->_reconnect;
-        if (not defined $self->_connected) {
+        if (not $self->_connected) {
             $self->_logdie(q{wasn't connected; couldn't _reconnect()});
         }
     }
@@ -382,7 +393,7 @@ sub send_frame {
     if (not defined $written) {
         $self->logger->warn("error writing frame <<$frame_string>>: $!");
     }
-    unless (defined $written && defined $self->_connected) {
+    unless (defined $written && $self->_connected) {
         $self->_reconnect;
         $self->send_frame($frame);
     }
@@ -494,7 +505,7 @@ sub receive_frame {
 
     my $timeout = exists $conf->{timeout} ? $conf->{timeout} :  $self->timeout;
 
-    unless (defined $self->_connected) {
+    unless ($self->_connected) {
         $self->_reconnect;
     }
 
@@ -1067,6 +1078,17 @@ all frames before it> (if you are using client acknowledgements):
 
 Always returns a true value.
 
+=head2 C<nack>
+
+This informs the remote end that you have been unable to process a
+received frame (if you are using client acknowledgements)
+(See individual stomp server documentation for information about
+additional fields that can be passed to alter NACK behavior):
+
+  $stomp->nack( { frame => $frame } );
+
+Always returns a true value.
+
 =head2 C<send_frame>
 
 If this module does not provide enough help for sending frames, you
